[jboss-cvs] JBossAS SVN: r58605 - trunk/testsuite/src/main/org/jboss/test/cluster/web/aop

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Sat Nov 18 06:54:27 EST 2006


Author: bstansberry at jboss.com
Date: 2006-11-18 06:54:26 -0500 (Sat, 18 Nov 2006)
New Revision: 58605

Modified:
   trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Address.java
   trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/AopBindingListener.java
   trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Person.java
   trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Student.java
Log:
Use @PojoCacheable

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Address.java
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Address.java	2006-11-18 11:54:08 UTC (rev 58604)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Address.java	2006-11-18 11:54:26 UTC (rev 58605)
@@ -21,18 +21,17 @@
   */
 package org.jboss.test.cluster.web.aop;
 
+import org.jboss.cache.pojo.annotation.PojoCacheable;
 
 
+
 /**
- * Test class for TreeCacheAOP.
+ * Test class for PojoCache.
  * Person is a POJO that will be instrumented with CacheInterceptor
  *
  * @version $Revision$
- * Annotation marker that is needed for fine-grained replication.
- * Note that we do it in 1.4 style now so it needs annotation compiler,
- * annotationc.
- * @@org.jboss.web.tomcat.tc5.session.AopMarker
  */
+ at PojoCacheable
 public class Address
 {
    String street = null;

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/AopBindingListener.java
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Person.java	2006-11-18 11:54:08 UTC (rev 58604)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Person.java	2006-11-18 11:54:26 UTC (rev 58605)
@@ -23,17 +23,16 @@
 
 import java.util.*;
 
+import org.jboss.cache.pojo.annotation.InstanceOfPojoCacheable;
 
+
 /**
- * Test class for TreeCacheAOP.
+ * Test class for PojoCache.
  * Person is a POJO that will be instrumented with CacheInterceptor
  *
  * @version $Revision$
- * Annotation marker that is needed for fine-grained replication.
- * Note that we do it in 1.4 style now so it needs annotation compiler,
- * annotationc.
- * @@org.jboss.web.tomcat.tc5.session.InstanceOfAopMarker
  */
+ at InstanceOfPojoCacheable
 public class Person
 {
    String name = null;

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Student.java
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Student.java	2006-11-18 11:54:08 UTC (rev 58604)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Student.java	2006-11-18 11:54:26 UTC (rev 58605)
@@ -22,13 +22,10 @@
 package org.jboss.test.cluster.web.aop;
 
 /**
- * Test class for TreeCacheAOP.
+ * Test class for PojoCache.
  * Student is a POJO that will be instrumented with CacheInterceptor
  *
  * @version $Revision$
- * Annotation marker that is needed for fine-grained replication.
- * Note that we do it in 1.4 style now so it needs annotation compiler,
- * annotationc.
  */
 public class Student extends Person
 {




More information about the jboss-cvs-commits mailing list
--- trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/AopBindingListener.java	2006-11-18 11:54:08 UTC (rev 58604)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/AopBindingListener.java	2006-11-18 11:54:26 UTC (rev 58605)
@@ -22,20 +22,17 @@
 
 package org.jboss.test.cluster.web.aop;
 
+import org.jboss.cache.pojo.annotation.PojoCacheable;
 import org.jboss.test.cluster.web.BindingListener;
 
 /**
  * Simple BindingListener subclass that declares the AopMarker interface
  * so it can be used in FIELD based replication tests.
  *
  * @author <a href="mailto://brian.stansberry@jboss.com">Brian Stansberry</a>
  * @version $Revision$
- *
- * Annotation marker that is needed for fine-grained replication.
- * Note that we do it in 1.4 style now so it needs annotation compiler,
- * annotationc.
- * @@org.jboss.web.tomcat.tc5.session.AopMarker
  */
+ at PojoCacheable
 public class AopBindingListener extends BindingListener
 {
 
@@ -22,20 +22,17 @@
 
 /**
- * Simple BindingListener subclass that declares the AopMarker interface
+ * Simple BindingListener subclass that declares the @PojoCacheable interface
  * so it can be used in FIELD based replication tests.
  *

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/web/aop/Person.java
===================================================================